Gaussian Inflection Spline Interpolation Continuum (GISIC)
==========================================================
GISIC is a python package for normalization of astronomical spectra.
It is designed to accommodate spectra with heavy molecular features due to high
elemental abundance enhancements.
GISIC performs a gaussian smoothing of the flux array, and identifies molecular bands based on a numerical gradient. Continuum points are then interpolated with a cubic spline.

